@@ -1,5 +1,5 @@
-from .webapi import MetaCatClient
-from .webapi import ServerError as MCServerError
+from .webapi import MetaCatClient, MCError
+from .webapi import ServerReportedError as MCServerError
 from .webapi import AuthenticationError
 from .webapi import WebAPIError as MCWebAPIError
 from .webapi import InvalidMetadataError as MCInvalidMetadataError
\ No newline at end of file
